@@ -2,8 +2,8 @@
 
 import datetime
 import json
-import mock
 import unittest
+from unittest import mock
 
 import libhoney
 
