@@ -13,6 +13,7 @@ import time
 import collections
 import concurrent.futures
 
+from platform import python_version
 from libhoney.version import VERSION
 from libhoney.internal import json_default_handler
 
@@ -22,6 +23,7 @@ try:
     from tornado.locks import Semaphore
     from tornado.queues import Queue, QueueFull
     from tornado.util import TimeoutError
+    from tornado import version as tornado_version
     has_tornado = True
 except ImportError:
     has_tornado = False
@@ -43,9 +45,12 @@ class Transmission():
         self.gzip_compression_level = gzip_compression_level
         self.gzip_enabled = gzip_enabled
 
-        user_agent = "libhoney-py/" + VERSION
         if user_agent_addition:
-            user_agent += " " + user_agent_addition
+            agent_template = "libhoney-py/{} {} python/{}"
+            user_agent = agent_template.format(VERSION, user_agent_addition, python_version())
+        else:
+            agent_template = "libhoney-py/{} python/{}"
+            user_agent = agent_template.format(VERSION, python_version())
 
         session = self._get_requests_session()
         session.headers.update({"User-Agent": user_agent})
@@ -69,9 +74,20 @@ class Transmission():
 
     @staticmethod
     def _get_requests_session():
-        # lazy load requests only when needed
-        import requests  # pylint: disable=import-outside-toplevel
-        return requests.Session()
+        # lazy load requests only when needed (for why, see #121)
+        from requests import Session  # pylint: disable=import-outside-toplevel
+        from requests.adapters import HTTPAdapter  # pylint: disable=import-outside-toplevel
+        from urllib3.util import Retry  # pylint: disable=import-outside-toplevel
+
+        retry_strategy = Retry(total=1,
+                               status_forcelist=[500, 503, 504, 408, 429],  # retry status codes
+                               allowed_methods=["POST"])  # allow 1 retry on post
+        http_adapter = HTTPAdapter(max_retries=retry_strategy)
+
+        session = Session()
+        session.mount("http://", http_adapter)
+        session.mount("https://", http_adapter)
+        return session
 
     def _init_logger(self):
         import logging  # pylint: disable=bad-option-value,import-outside-toplevel
@@ -265,9 +281,12 @@ if has_tornado:
             self.max_batch_size = max_batch_size
             self.send_frequency = send_frequency
 
-            user_agent = "libhoney-py/" + VERSION
             if user_agent_addition:
-                user_agent += " " + user_agent_addition
+                agent_template = "libhoney-py/{} (tornado/{}) {} python/{}"
+                user_agent = agent_template.format(VERSION, tornado_version, user_agent_addition, python_version())
+            else:
+                agent_template = "libhoney-py/{} (tornado/{}) python/{}"
+                user_agent = agent_template.format(VERSION, tornado_version, python_version())
 
             self.http_client = AsyncHTTPClient(
                 force_instance=True,
